****November 13, 2014
****This file runs the analyses that are presented in chapter 4 of the book

****use the following datafile when running this do file: chapters345.dta

log using ch4results.log, replace

label var homeobs "observation from the home government of the AG, coded 1 for plaintiff, -1 for defendant, 0 otherwise"


gen homeltsurv=homeobs*ltsurv
gen homesurv=homeobs*surv
gen agecent=age2-58
gen homeagecent=homeobs*agecent
gen homesixth=homeobs*sixth

***Table 4.1

sum AGforPl homeobs sixth ltsurv surv agecent if homeobs~=. & AGforPl~=. & homeobs ~=. & ltsurv ~=. & surv~=.

***Table 4.2, Model 1

probit AGforPl homeobs netobs agecent homeagecent sixth homesixth ltsurv homeltsurv, cluster(casenumber)

***Table 4.2, Model 2

probit AGforPl homeobs netobs agecent homeagecent sixth homesixth surv homesurv, cluster(casenumber)

***Figure 4.4


**plot the conditional effects for different values of homeobs and the interaction conditions

estsimp probit AGforPl netobs homeobs homeltsurv ltsurv sixth homesixth agecent homeagecent, cluster(casenumber)


*baseline: all vars at mean, home and homeinteractions, sixth at zero

setx netobs mean (homeobs homeagecent agecent sixth homesixth homeltsurv) 0 (ltsurv) .41
simqi


*baseline with homeobs=1

setx netobs mean (homeagecent agecent sixth homesixth) 0 homeobs 1 (homeltsurv ltsurv) .41
simqi
  

*min effect overall: homeobs when netobs at mean, agecent=16, ltsurv=0, sixth=0

setx netobs mean (homeltsurv ltsurv sixth homesixth homeobs homeagecent) 0 agecent 16 
simqi
setx netobs mean (homeltsurv ltsurv sixth homesixth) 0 homeobs 1 (agecent homeagecent) 16 
simqi


*max effect overall: homeobs when netobs at mean, agecent=-15 (min), ltsurv=1, and sixth=0

setx netobs mean (homeltsurv homesixth sixth homeagecent) 0 homeobs 0 agecent -15 ltsurv 1 
simqi

setx netobs mean (agecent homeagecent) -15 (homesixth sixth) 0  (homeobs homeltsurv ltsurv) 1 
simqi


**Table 4.3, Model 1

probit AGforPl homeobs netobs if AGInd>0 & agecent>11 | AGInd>0 & ltsurv==0, cluster(casenumber)

**Table 4.3, Model 2

probit AGforPl homeobs netobs if AGInd>0 & agecent<12 & ltsurv>0, cluster(casenumber)


***Create variables used in analysis presented in Table 4.4

*create variable "vulnerable" indicating that the AG is likely responsive to home government influence due to age and the likelihood of survival of the prime minister's party

gen vulnerable=0

replace vulnerable=1 if agecent<12 & ltsurv>0

 
**create variable capturing set of rulings where AG agrees with homeobs, meaning there is threat of homecooking (AG adopts position taken by his/her home government)

gen homecook=0

replace homecook=1 if AGforPl==1 & homeobs==1
replace homecook=1 if AGforPl==0 & homeobs==-1

 
**create variable capturing set of rulings where homecooking is a threat and the AG is responsive to that influence 
 
gen suspect=0
replace suspect=1 if homecook==1 & vulnerable==1


**craete interaction term between suspect and AGforPl, so we can test to see if the AG’s position is less influential on ECJ rulings when it is suspect

gen AGforPlsuspect= AGforPl*suspect

***Tabel 4.4

probit NewECJPlAgree AGforPl AGforPlsuspect suspect normgdpobs  CommIsPl CommIsDef CommObsPl CommObsDef govislit normgdpobsgov if AGInd>0, cluster(casenumber)


***Appendix interpretation of results from Table 4.4

**the lincom below is the same as just using lincom AGforPlcomprommised + suspect, but this spells it out 

lincom AGforPl + AGforPlsuspect + suspect - AGforPl  

**simulated effects
drop b1 b2 b3 b4 b5 b6 b7 b8 b9

estsimp probit  NewECJPlAgree AGforPl AGforPlsuspect suspect normgdpobs  CommIsPl CommIsDef CommObsPl CommObsDef govislit normgdpobsgov if AGInd>0, cluster(casenumber)



*simulated effect of change in AGforPl from 0 to 1 when AG opinion is not suspect 

setx (normgdpobs)  mean (CommObsPl CommObsDef CommIsPl CommIsDef govislit normgdpobsgov) 0 (AGforPl AGforPlsuspect suspect) 0
simqi

setx (normgdpobs)  mean (CommObsPl CommObsDef CommIsPl CommIsDef govislit normgdpobsgov) 0 (AGforPl) 1 (AGforPlsuspect suspect) 0
simqi

*simulated effect of change in AGforPl from 0 to 1 when AG opinion is suspect

setx (normgdpobs)  mean (CommObsPl CommObsDef CommIsPl CommIsDef govislit normgdpobsgov) 0 (AGforPl AGforPlsuspect) 0 (suspect) 1
simqi

setx (normgdpobs)  mean (CommObsPl CommObsDef CommIsPl CommIsDef govislit normgdpobsgov) 0 (AGforPl AGforPlsuspect suspect) 1
simqi 

log close



